@@ -6,9 +6,6 @@ create table `carp_file_import`
 (
     `id`           bigint       not null auto_increment comment '自增主键',
     `namespace`    varchar(64)  not null default 'default' comment '命名空间',
-    `app`          varchar(64)  not null default 'default' comment '应用',
-    `env`          varchar(64)  not null default 'default' comment '环境',
-    `tenant`       varchar(64)  not null default 'default' comment '租户',
     `biz_code`     varchar(64)  not null comment '业务编码',
     `sub_biz_code` varchar(64) comment '子业务编码',
     `type`         varchar(64)  not null comment '导入类型。excel, csv, json 等',
@@ -25,6 +22,5 @@ create table `carp_file_import`
     `editor`       varchar(32) comment '修改人',
     `update_time`  datetime     not null default current_timestamp on update current_timestamp comment '更新时间',
     primary key (`id`),
-     key `idx_key` (`namespace`,`app`,`env`,`tenant`),
-     key `idx_file_name` (`namespace`,`app`,`env`,`tenant`, `file_name`)
+     key `idx_file_name` (`namespace`, `file_name`)
 ) engine = innodb comment='文件上传';
\ No newline at end of file
